@@ -37,14 +37,14 @@ urlpatterns = patterns(
 
     # Admin ajax urls
     (
-        r'^admin/molo/publish-ajax/$',
+        r'^admin/molo/publish-ajax/(?P<app_label>[\w-]+)/(?P<model>[\w-]+)/$',
         'molo.admin_views.publish_ajax',
         {},
         'molo-publish-ajax',
     ),
 
     (
-        r'^admin/molo/unpublish-ajax/$',
+        r'^admin/molo/unpublish-ajax/(?P<app_label>[\w-]+)/(?P<model>[\w-]+)/$',
         'molo.admin_views.unpublish_ajax',
         {},
         'molo-unpublish-ajax',
